==> hadoop-3.2.4-src.tar.gz: hadoop-3.2.4-src/hadoop-yarn-project/hadoop-yarn/hadoop-yarn-ui/src/main/webapp/app/routes/yarn-component-instance/info.js <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import Ember from 'ember';
import AbstractRoute from '../abstract';

export default AbstractRoute.extend({
  model(params, transition) {
    var instanceName = params.instance_name;
    transition.send('updateBreadcrumbs', params.appid, params.service, params.component_name, instanceName);
    return Ember.RSVP.hash({
      appId: params.appid,
      serviceName: params.service,
      componentName: params.component_name,
      instanceName: instanceName,
      container: this.store.query('yarn-component-instance', {appId: params.appid}).then(function(instances) {
        if (instances && instances.findBy('containerId', params.containerid)) {
          return instances.findBy('containerId', params.containerid);
        }
        return null;
      }, function() {
        return null;
      }),
    });
  },

  unloadAll() {
    this.store.unloadAll('yarn-component-instance');
  }
});

==> hadoop-3.4.0-src.tar.gz: hadoop-3.4.0-src/hadoop-yarn-project/hadoop-yarn/hadoop-yarn-ui/src/main/webapp/app/routes/yarn-component-instance/info.js <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import Ember from 'ember';
import AbstractRoute from '../abstract';

export default AbstractRoute.extend({
  model(params, transition) {
    var instanceName = params.instance_name;
    transition.send('updateBreadcrumbs', params.appid, params.service, params.component_name, instanceName);
    return Ember.RSVP.hash({
      appId: params.appid,
      serviceName: params.service,
      componentName: params.component_name,
      instanceName: instanceName,
      container: this.store.query('yarn-component-instance', {appId: params.appid}).then(function(instances) {
        if (instances && instances.findBy('containerId', params.containerid)) {
          return instances.findBy('containerId', params.containerid);
        }
        return null;
      }, function() {
        return null;
      }),
    });
  },

  afterModel(model) {
    const appContrl = this.controllerFor('application');
    model.userInfo = appContrl.get('userInfo');
  },

  unloadAll() {
    this.store.unloadAll('yarn-component-instance');
  }
});
